pub struct MessageActionDataBody {
pub message_timetoken: String,
pub action_timetoken: String,
pub type: String,
pub value: String,
}Expand description
Information about message action for which update has been generated.
Fields
message_timetoken: StringTimetoken of message for which action has been added / removed.
action_timetoken: StringTimetoken of message action which has been added / removed.
type: StringMessage action type.
value: StringValue associated with message action type.