pub struct RevokeTokenRequest<T, D> { /* private fields */ }Expand description
The RevokeTokenRequestBuilder is used to build revoke access token
permissions to access specific resource endpoints request that is sent to
the PubNub network.
This struct used by the revoke_token method of the PubNubClient.
The revoke_token method is used to revoke access token permissions.